==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/lrc-IQ.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "lrc-IQ",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun"
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun"
  ],
  day_stand_alone_abbreviated => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun"
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun"
  ],
  era_abbreviated => [
    "BCE",
    "CE"
  ],
  era_narrow => [
    "BCE",
    "CE"
  ],
  era_wide => [
    "BCE",
    "CE"
  ],
  first_day_of_week => 6,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Northern Luri",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}"
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}"
  ],
  name => "Northern Luri Iraq",
  native_language => "\N{U+0644}\N{U+06ca}\N{U+0631}\N{U+06cc} \N{U+0634}\N{U+0648}\N{U+0645}\N{U+0627}\N{U+0644}\N{U+06cc}",
  native_name => "\N{U+0644}\N{U+06ca}\N{U+0631}\N{U+06cc} \N{U+0634}\N{U+0648}\N{U+0645}\N{U+0627}\N{U+0644}\N{U+06cc} IQ",
  native_script => undef,
  native_territory => "IQ",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0623}\N{U+06a4}\N{U+0623}\N{U+0644}",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0623}\N{U+06a4}\N{U+0623}\N{U+0644}",
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+062f}\N{U+0648}\N{U+06cc}\N{U+0648}\N{U+0645}",
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0633}\N{U+0626}\N{U+06cc}\N{U+0648}\N{U+0645}",
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0686}\N{U+0627}\N{U+0631}\N{U+0648}\N{U+0645}"
  ],
  script => undef,
  territory => "Iraq",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/lrc-IQ.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "lrc-IQ",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun",
  ],
  day_stand_alone_abbreviated => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Mon",
    "Tue",
    "Wed",
    "Thu",
    "Fri",
    "Sat",
    "Sun",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 6,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Northern Luri",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+06a4}\N{U+06cc}\N{U+06d5}",
    "\N{U+0641}\N{U+0626}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+06d5}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0633}",
    "\N{U+0622}\N{U+06a4}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}\N{U+06cc}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0623}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0659}\N{U+0644}\N{U+0627}",
    "\N{U+0622}\N{U+06af}\N{U+0648}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+0626}\N{U+067e}\N{U+062a}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+0626}\N{U+0648}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+06a4}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+06a4}\N{U+0627}\N{U+0645}\N{U+0631}",
    "\N{U+062f}\N{U+0626}\N{U+0633}\N{U+0627}\N{U+0645}\N{U+0631}",
  ],
  name => "Northern Luri Iraq",
  native_language => "\N{U+0644}\N{U+06ca}\N{U+0631}\N{U+06cc} \N{U+0634}\N{U+0648}\N{U+0645}\N{U+0627}\N{U+0644}\N{U+06cc}",
  native_name => "\N{U+0644}\N{U+06ca}\N{U+0631}\N{U+06cc} \N{U+0634}\N{U+0648}\N{U+0645}\N{U+0627}\N{U+0644}\N{U+06cc} IQ",
  native_script => undef,
  native_territory => "IQ",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0623}\N{U+06a4}\N{U+0623}\N{U+0644}",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0623}\N{U+06a4}\N{U+0623}\N{U+0644}",
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+062f}\N{U+0648}\N{U+06cc}\N{U+0648}\N{U+0645}",
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0633}\N{U+0626}\N{U+06cc}\N{U+0648}\N{U+0645}",
    "\N{U+0686}\N{U+0627}\N{U+0631}\N{U+0623}\N{U+06a9} \N{U+0686}\N{U+0627}\N{U+0631}\N{U+0648}\N{U+0645}",
  ],
  script => undef,
  territory => "Iraq",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 32,
}
